netapp_ontap.models.plex_resync API documentation
Description: Copyright &copy; 2020 NetApp Inc. All rights reserved.

# Module `netapp_ontap.models.plex_resync`

Copyright © 2020 NetApp Inc. All rights reserved.

## Classes

`class PlexResyncSchema (*, only: typing.Union = None, exclude: typing.Union = (), many: bool = False, context: typing.Dict = None, load_only: typing.Union = (), dump_only: typing.Union = (), partial: typing.Union = False, unknown: str = None)`

  The fields of the PlexResync object

  ### Ancestors

  - netapp_ontap.resource.ResourceSchema
  - marshmallow.schema.Schema
  - marshmallow.base.SchemaABC

  ### Class variables

  `active GET`

    Plex is being resynchronized to its mirrored plex

  `level GET`

    Plex resyncing level

    Valid choices:

    - full
    - incremental
  `percent GET`

    Plex resyncing percentage

    Example: 10